@@ -8,24 +8,23 @@
 This file INTENTIONALLY has NO module dependencies!
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
+from .compatibility import *  # NOQA
 
-import imp
+import csv
+import io
 import itertools
 import os
 import re
-import sys
-import zipfile
-import io
+import shutil
 import string
 import subprocess
-import csv
-import shutil
+import sys
 import tempfile
+import zipfile
 
-from h2o.exceptions import H2OValueError
-from h2o.utils.compatibility import *  # NOQA
-from h2o.utils.typechecks import assert_is_type, is_type, numeric
 from h2o.backend.server import H2OLocalServer
+from h2o.exceptions import H2OValueError
+from h2o.utils.typechecks import assert_is_type, is_type, numeric
 
 _id_ctr = 0
 
@@ -66,36 +65,47 @@ def temp_ctr():
     return _id_ctr
 
 
-def can_use_pandas():
-    try:
-        imp.find_module('pandas')
+def is_module_available(mod):
+    if mod in sys.modules and sys.modules[mod] is not None:  # fast track + safer in unusual environments 
         return True
-    except ImportError:
-        return False
+    if PY2:
+        import imp
+        try:
+            imp.find_module(mod)
+            return True
+        except ImportError:
+            return False
+        
+    import importlib.util
+    return importlib.util.find_spec(mod) is not None
+
+
+def can_use_pandas():
+    return is_module_available('pandas')
 
 
 def can_use_numpy():
-    try:
-        imp.find_module('numpy')
-        return True
-    except ImportError:
-        return False
+    return is_module_available('numpy')
 
 
 _url_safe_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_.~"
 _url_chars_map = [chr(i) if chr(i) in _url_safe_chars else "%%%02X" % i for i in range(256)]
 
+
 def url_encode(s):
     # Note: type cast str(s) will not be needed once all code is made compatible
     return "".join(_url_chars_map[c] for c in bytes_iterator(s))
 
+
 def quote(s):
     return url_encode(s)
 
+
 def clamp(x, xmin, xmax):
     """Return the value of x, clamped from below by `xmin` and from above by `xmax`."""
     return max(xmin, min(x, xmax))
 
+
 def _gen_header(cols):
     return ["C" + str(c) for c in range(1, cols + 1, 1)]
 
@@ -141,15 +151,31 @@ def stringify_dict(d):
     return stringify_list(["{'key': %s, 'value': %s}" % (_quoted(k), v) for k, v in d.items()])
 
 
+def stringify_dict_as_map(d):
+    return "{%s}" % ",".join(["%s: %s" % (_quoted(k), stringify_object(v, stringify_dict_as_map)) for k, v in d.items()])
+
+
 def stringify_list(arr):
     return "[%s]" % ",".join(stringify_list(item) if isinstance(item, list) else _str(item)
                              for item in arr)
 
+
+def stringify_object(o, dict_function=stringify_dict):
+    if isinstance(o, dict):
+        return dict_function(o)
+    elif isinstance(o, list):
+        return stringify_list(o)
+    else:
+        return _str(o)
+
+
 def _str(item):
     return _str_tuple(item) if isinstance(item, tuple) else str(item)
 
+
 def _str_tuple(t):
-    return "{%s}" % ",".join(["%s: %s" % (ti[0], str(ti[1])) for ti in zip(list(string.ascii_lowercase), t)])
+    return "{%s}" % ",".join(["%s: %s" % (ti[0], _str(ti[1])) for ti in zip(list(string.ascii_lowercase), t)])
+
 
 def _is_list(l):
     return isinstance(l, (tuple, list))
@@ -175,6 +201,7 @@ def _handle_pandas_data_frame(python_obj, header):
     data = _handle_python_lists(python_obj.values.tolist(), -1)[1]
     return list(str(c) for c in python_obj.columns), data
 
+
 def _handle_python_dicts(python_obj, check_header):
     header = list(python_obj.keys()) if python_obj else _gen_header(1)
     is_valid = all(re.match(r"^[a-zA-Z_][a-zA-Z0-9_.]*$", col) for col in header)  # is this a valid header?
